@@ -45,7 +45,7 @@ class OERTypeExtender(object):
                      widget=MultiSelectionWidget(
                          label=_(u'OER Type'),
                          label_msgid='label_oer_type',
-                         description=_(u'The type of resourse'),
+                         description=_(u'The type of resource'),
                          description_msgid=_(u'help_oer_type'),
                          format='select',
                          ),
