@@ -126,6 +126,10 @@ def setupPortalContent(portal):
 
     syndicateFolderishObject(portal, event=None)
 
+    # Set default eduCommons colors
+    bprops = portal.portal_skins.custom.base_properties
+    bprops.manage_changeProperties(portalHeaderBackgroundColor="#153588")
+
     # If Members, news, and/or event objects exist, remove them
     delobjs = []
     if 'Members' in existing:
